(function ($, Drupal, drupalSettings, once) {
  'use strict';

  Drupal.behaviors.contribTodoList = {
    attach: function (context, settings) {
      once('todo-modal', '.contrib-todo-list', context).forEach(function(todomodal) {
        const todobtn = document.querySelector('.todo-btn');
        if (!todobtn) return;

        todobtn.addEventListener('click', () => {
          todomodal.classList.toggle('show');
        });
      });

      once('todo-form', '.todo-add-form', context).forEach(function(form) {
        form.addEventListener('submit', function(e) {
          e.preventDefault();
          const todoText = document.getElementById('todo-text').value;
          const nodeId = drupalSettings.contrib_todo_list.nodeId;

          fetch('/todo/add', {
            method: 'POST',
            headers: {
              'Content-Type': 'application/json',
            },
            body: JSON.stringify({
              node_id: nodeId,
              todo_text: todoText,
              state: 'pending'
            })
          })
          .then(response => response.json())
          .then(data => {
            document.getElementById('todo-text').value = '';
            const todosWrapper = document.querySelector('.todos-wrapper');
            const todosList = document.querySelector('.todos-list');

            const newTodoHtml = `
              <div class="todo-item todo-state-pending" data-todo-id="${data.todo_id}">
                <div class="todo-upper">
                  <div class="todo-content">
                    ${data.text}
                  </div>
                  <div class="todo-dropdown-container">
                    <button class="todo-dropdown-toggle" type="button" aria-expanded="false">
                      <span aria-hidden="true">&#8230;</span>
                    </button>
                    <ul class="custom-dropdown-menu">
                      <li>
                        <a href="#" class="todo-state-action disabled" data-state="pending" aria-disabled="true">
                          ${Drupal.t('Pending')}
                        </a>
                      </li>
                      <li>
                        <a href="#" class="todo-state-action" data-state="in-progress">
                          ${Drupal.t('In Progress')}
                        </a>
                      </li>
                      <li>
                        <a href="#" class="todo-state-action" data-state="completed">
                          ${Drupal.t('Completed')}
                        </a>
                      </li>
                      <li class="divider"></li>
                      <li><a href="#" class="todo-delete-action">
                        ${Drupal.t('Delete')}
                        <svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="24" height="24" viewBox="0,0,256,256"
                             style="fill:#FA5252;">
                          <g fill="#fa5252" fill-rule="nonzero" stroke="none" stroke-width="1" stroke-linecap="butt" stroke-linejoin="miter" stroke-miterlimit="10" stroke-dasharray="" stroke-dashoffset="0" font-family="none" font-weight="none" font-size="none" text-anchor="none" style="mix-blend-mode: normal"><g transform="scale(8.53333,8.53333)"><path d="M13,3c-0.26757,-0.00363 -0.52543,0.10012 -0.71593,0.28805c-0.1905,0.18793 -0.29774,0.44436 -0.29774,0.71195h-5.98633c-0.36064,-0.0051 -0.69608,0.18438 -0.87789,0.49587c-0.18181,0.3115 -0.18181,0.69676 0,1.00825c0.18181,0.3115 0.51725,0.50097 0.87789,0.49587h18c0.36064,0.0051 0.69608,-0.18438 0.87789,-0.49587c0.18181,-0.3115 0.18181,-0.69676 0,-1.00825c-0.18181,-0.3115 -0.51725,-0.50097 -0.87789,-0.49587h-5.98633c0,-0.26759 -0.10724,-0.52403 -0.29774,-0.71195c-0.1905,-0.18793 -0.44836,-0.29168 -0.71593,-0.28805zM6,8v16c0,1.105 0.895,2 2,2h14c1.105,0 2,-0.895 2,-2v-16z"></path></g></g>
                        </svg>
                        </a></li>
                    </ul>
                  </div>
                </div>

                <div class="todo-actions">
                  <div class="todo-lower">
                    <div class="todo-lower-left">
                      <span class="todo-state-label">${Drupal.t('Pending')}</span>
                    </div>
                    <div class="todo-lower-right">
                      <div class='add-pin' data-todo-id="${data.todo_id}">
                        <svg width="28" height="28" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M15.9894 4.9502L16.52 4.42014L16.52 4.42014L15.9894 4.9502ZM8.73845 19.429L8.20785 19.9591L8.73845 19.429ZM4.62176 15.3081L5.15236 14.7781L4.62176 15.3081ZM17.567 14.9943L17.3032 14.2922L17.567 14.9943ZM15.6499 15.7146L15.9137 16.4167L15.6499 15.7146ZM8.33227 8.38177L7.62805 8.12375H7.62805L8.33227 8.38177ZM9.02673 6.48636L9.73095 6.74438L9.02673 6.48636ZM5.84512 10.6735L6.04445 11.3965H6.04445L5.84512 10.6735ZM7.30174 10.1351L6.86354 9.52646L6.86354 9.52646L7.30174 10.1351ZM7.6759 9.79038L8.24673 10.2768H8.24673L7.6759 9.79038ZM14.2511 16.3805L14.7421 16.9475L14.7421 16.9475L14.2511 16.3805ZM13.3807 18.2012L12.6575 18.0022V18.0022L13.3807 18.2012ZM13.917 16.7466L13.3076 16.3094L13.3076 16.3094L13.917 16.7466ZM2.71854 12.7552L1.96855 12.76V12.76L2.71854 12.7552ZM2.93053 11.9521L2.28061 11.5778H2.28061L2.93053 11.9521ZM11.3053 21.3431L11.3064 20.5931H11.3064L11.3053 21.3431ZM12.0933 21.1347L11.7216 20.4833L11.7216 20.4833L12.0933 21.1347ZM21.9652 12.3049L22.6983 12.4634L21.9652 12.3049ZM11.6973 2.03606L11.8589 2.76845L11.6973 2.03606ZM22.3552 10.6303C22.1511 10.2699 21.6934 10.1433 21.333 10.3475C20.9726 10.5516 20.846 11.0093 21.0502 11.3697L22.3552 10.6303ZM18.006 8.03006C18.2988 8.3231 18.7737 8.32334 19.0667 8.0306C19.3597 7.73786 19.36 7.26298 19.0672 6.96994L18.006 8.03006ZM9.26905 18.8989L5.15236 14.7781L4.09116 15.8382L8.20785 19.9591L9.26905 18.8989ZM17.3032 14.2922L15.3861 15.0125L15.9137 16.4167L17.8308 15.6964L17.3032 14.2922ZM9.03649 8.63979L9.73095 6.74438L8.32251 6.22834L7.62805 8.12375L9.03649 8.63979ZM6.04445 11.3965C6.75591 11.2003 7.29726 11.0625 7.73995 10.7438L6.86354 9.52646C6.6906 9.65097 6.46608 9.72428 5.64578 9.95044L6.04445 11.3965ZM7.62805 8.12375C7.3351 8.92332 7.24345 9.14153 7.10507 9.30391L8.24673 10.2768C8.60048 9.86175 8.78237 9.33337 9.03649 8.63979L7.62805 8.12375ZM7.73995 10.7438C7.92704 10.6091 8.09719 10.4523 8.24673 10.2768L7.10507 9.30391C7.03377 9.38757 6.95268 9.46229 6.86354 9.52646L7.73995 10.7438ZM15.3861 15.0125C14.697 15.2714 14.1717 15.4571 13.7601 15.8135L14.7421 16.9475C14.9029 16.8082 15.1193 16.7152 15.9137 16.4167L15.3861 15.0125ZM14.1038 18.4001C14.3291 17.5813 14.4022 17.3569 14.5263 17.1838L13.3076 16.3094C12.9903 16.7517 12.853 17.2919 12.6575 18.0022L14.1038 18.4001ZM13.7601 15.8135C13.5904 15.9605 13.4385 16.1269 13.3076 16.3094L14.5263 17.1838C14.5888 17.0968 14.6612 17.0175 14.7421 16.9475L13.7601 15.8135ZM5.15236 14.7781C4.50623 14.1313 4.06806 13.691 3.78374 13.3338C3.49842 12.9753 3.46896 12.8201 3.46852 12.7505L1.96855 12.76C1.97223 13.3422 2.26135 13.8297 2.6101 14.2679C2.95984 14.7073 3.47123 15.2176 4.09116 15.8382L5.15236 14.7781ZM5.64578 9.95044C4.80056 10.1835 4.10403 10.3743 3.58304 10.5835C3.06349 10.792 2.57124 11.0732 2.28061 11.5778L3.58045 12.3264C3.61507 12.2663 3.717 12.146 4.14187 11.9755C4.56531 11.8055 5.16345 11.6394 6.04445 11.3965L5.64578 9.95044ZM3.46852 12.7505C3.46758 12.6016 3.50623 12.4553 3.58045 12.3264L2.28061 11.5778C2.07362 11.9372 1.96593 12.3452 1.96855 12.76L3.46852 12.7505ZM8.20785 19.9591C8.83172 20.5836 9.34472 21.0987 9.78654 21.4506C10.2271 21.8015 10.718 22.0922 11.3042 22.0931L11.3064 20.5931C11.237 20.593 11.0815 20.5644 10.7211 20.2773C10.3619 19.9912 9.91931 19.5499 9.26905 18.8989L8.20785 19.9591ZM12.6575 18.0022C12.4133 18.8897 12.2463 19.4924 12.0752 19.9188C11.9034 20.3467 11.7822 20.4487 11.7216 20.4833L12.4651 21.7861C12.9741 21.4956 13.2573 21.0004 13.4672 20.4775C13.6777 19.9532 13.8695 19.2516 14.1038 18.4001L12.6575 18.0022ZM11.3042 22.0931C11.7113 22.0937 12.1115 21.9879 12.4651 21.7861L11.7216 20.4833C11.5951 20.5555 11.452 20.5933 11.3064 20.5931L11.3042 22.0931ZM17.8308 15.6964C19.1922 15.1849 20.2941 14.773 21.0771 14.3384C21.8719 13.8973 22.5084 13.3416 22.6983 12.4634L21.2322 12.1464C21.178 12.3968 21.0002 12.6655 20.3492 13.0268C19.6865 13.3946 18.7113 13.7632 17.3032 14.2922L17.8308 15.6964ZM16.52 4.42014C15.4841 3.3832 14.6481 2.54353 13.9246 2.00638C13.1909 1.46165 12.4175 1.10912 11.5357 1.30367L11.8589 2.76845C12.1086 2.71335 12.4278 2.7633 13.0305 3.21075C13.6434 3.66579 14.3877 4.40801 15.4588 5.48026L16.52 4.42014ZM9.73095 6.74438C10.2526 5.32075 10.6162 4.33403 10.9813 3.66315C11.3403 3.00338 11.6091 2.82357 11.8589 2.76845L11.5357 1.30367C10.6541 1.49819 10.1006 2.14332 9.6637 2.94618C9.23286 3.73793 8.82695 4.85154 8.32251 6.22834L9.73095 6.74438ZM21.0502 11.3697C21.2515 11.7251 21.2745 11.9507 21.2322 12.1464L22.6983 12.4634C22.8404 11.8064 22.6796 11.2027 22.3552 10.6303L21.0502 11.3697ZM15.4588 5.48026L18.006 8.03006L19.0672 6.96994L16.52 4.42014L15.4588 5.48026Z" fill="#1C274C"/>
                        <path d="M1.4694 21.4697C1.17666 21.7627 1.1769 22.2376 1.46994 22.5304C1.76298 22.8231 2.23786 22.8229 2.5306 22.5298L1.4694 21.4697ZM7.18383 17.8719C7.47657 17.5788 7.47633 17.1039 7.18329 16.8112C6.89024 16.5185 6.41537 16.5187 6.12263 16.8117L7.18383 17.8719ZM2.5306 22.5298L7.18383 17.8719L6.12263 16.8117L1.4694 21.4697L2.5306 22.5298Z" fill="#1C274C"/>
                        </svg>
                      </div>
                      <div class="icon-share-wrapper" title="${Drupal.t('Share')}" data-shared="0">
                        <svg width="28" height="28" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <g id="Communication / Share_iOS_Export">
                        <path id="Vector" d="M9 6L12 3M12 3L15 6M12 3V13M7.00023 10C6.06835 10 5.60241 10 5.23486 10.1522C4.74481 10.3552 4.35523 10.7448 4.15224 11.2349C4 11.6024 4 12.0681 4 13V17.8C4 18.9201 4 19.4798 4.21799 19.9076C4.40973 20.2839 4.71547 20.5905 5.0918 20.7822C5.5192 21 6.07899 21 7.19691 21H16.8036C17.9215 21 18.4805 21 18.9079 20.7822C19.2842 20.5905 19.5905 20.2839 19.7822 19.9076C20 19.4802 20 18.921 20 17.8031V13C20 12.0681 19.9999 11.6024 19.8477 11.2349C19.6447 10.7448 19.2554 10.3552 18.7654 10.1522C18.3978 10 17.9319 10 17 10" stroke="#000000" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
                        </g>
                        </svg>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            `;

            if (!todosList) {
              todosWrapper.innerHTML = `<div class="todos-list">${newTodoHtml}</div>`;
            } else {
              todosList.insertAdjacentHTML('beforeend', newTodoHtml);
            }

            Drupal.attachBehaviors();
          });
        });
      });

      once('todo-btn-delete', '.btn-todo-delete', context).forEach(function(button) {
        button.addEventListener('click', () => {
          const todoId = button.dataset.todoId;
          const todoItem = button.closest('.todo-item');

          fetch(`/todo/${todoId}`, {
            method: 'POST',
            headers: {
              'Content-Type': 'application/json',
            },
            body: JSON.stringify({})
          })
          .then(response => {
            if (response.ok) {
              todoItem.remove();
            }
          });
        });
      });

      once('todo-state', '.todo-state-select', context).forEach(function(select) {
        select.addEventListener('change', function() {
          const todoId = this.closest('.todo-item').dataset.todoId;
          const todoItem = this.closest('.todo-item');
          const newState = this.value;

          fetch(`/todo/${todoId}/state`, {
            method: 'POST',
            headers: {
              'Content-Type': 'application/json',
            },
            body: JSON.stringify({ state: newState })
          })
          .then(response => response.json())
          .then(data => {
            if (data.status) {
              todoItem.className = `todo-item todo-state-${newState.replace(/_/g, '-')}`;
            }
          });
        });
      });

      once('todo-dropdown', '.todo-dropdown-container', context).forEach(function(container) {
        const toggleButton = container.querySelector('.todo-dropdown-toggle');
        const dropdownMenu = container.querySelector('.custom-dropdown-menu');

        toggleButton.addEventListener('click', function(e) {
          e.stopPropagation();
          const isExpanded = toggleButton.getAttribute('aria-expanded') === 'true';

          document.querySelectorAll('.todo-dropdown-container .custom-dropdown-menu.show').forEach(function(menu) {
            if (menu !== dropdownMenu) {
              menu.classList.remove('show');
              menu.closest('.todo-dropdown-container').querySelector('.todo-dropdown-toggle')
                .setAttribute('aria-expanded', 'false');
            }
          });

          dropdownMenu.classList.toggle('show');
          toggleButton.setAttribute('aria-expanded', !isExpanded);
        });
      });

      once('todo-dropdown-document', 'body', context).forEach(function(body) {
        document.addEventListener('click', function(e) {
          if (!e.target.closest('.todo-dropdown-container')) {
            document.querySelectorAll('.todo-dropdown-container .custom-dropdown-menu.show').forEach(function(menu) {
              menu.classList.remove('show');
              menu.closest('.todo-dropdown-container').querySelector('.todo-dropdown-toggle')
                .setAttribute('aria-expanded', 'false');
            });
          }
        });
      });

      once('todo-state-actions-container', '.custom-dropdown-menu', context).forEach(function(menu) {
        menu.addEventListener('click', function(e) {
          const stateLink = e.target.closest('.todo-state-action:not(.disabled)');
          if (stateLink) {
            e.preventDefault();
            e.stopPropagation();

            const todoItem = this.closest('.todo-item');
            const todoId = todoItem.dataset.todoId;
            const newState = stateLink.dataset.state;
            const stateText = stateLink.textContent.trim();

            this.classList.remove('show');
            const toggleButton = this.closest('.todo-dropdown-container').querySelector('.todo-dropdown-toggle');
            toggleButton.setAttribute('aria-expanded', 'false');

            fetch(`/todo/${todoId}/state`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'X-CSRF-Token': drupalSettings.ajaxPageState.csrf_token
                },
                body: JSON.stringify({ state: newState })
            })
            .then(response => {
                if (response.ok) {
                  const oldStateClass = todoItem.className.match(/todo-state-[a-zA-Z-]+/);
                    if (oldStateClass) {
                        todoItem.classList.remove(oldStateClass[0]);
                    }
                    todoItem.classList.add(`todo-state-${newState}`);

                    const stateLabel = todoItem.querySelector('.todo-state-label');
                    if (stateLabel) {
                        stateLabel.textContent = stateText;
                    }
                    const stateLinks = todoItem.querySelectorAll('.todo-state-action');
                    stateLinks.forEach(function(link) {
                        if (link.dataset.state === newState) {
                            link.classList.add('disabled');
                            link.setAttribute('aria-disabled', 'true');
                        } else {
                            link.classList.remove('disabled');
                            link.removeAttribute('aria-disabled');
                        }
                    });
                }
            })
            .catch(error => {
            });

          }
        });
      });

      once('todo-delete-actions-container', '.custom-dropdown-menu', context).forEach(function(menu) {
        menu.addEventListener('click', function(e) {
          const deleteLink = e.target.closest('.todo-delete-action');
          if (deleteLink) {
            e.preventDefault();
            e.stopPropagation();

            this.classList.remove('show');
            const toggleButton = this.closest('.todo-dropdown-container').querySelector('.todo-dropdown-toggle');
            toggleButton.setAttribute('aria-expanded', 'false');

            const todoItem = this.closest('.todo-item');
            const todoId = todoItem.dataset.todoId;


            fetch(`/todo/${todoId}`, {
              method: 'POST',
              headers: {
                'Content-Type': 'application/json',
                'X-CSRF-Token': drupalSettings.ajaxPageState.csrf_token
              },
              body: JSON.stringify({})
            })
              .then(response => {
                if (response.ok) {
                  todoItem.remove();
                  const pinElement = document.querySelector(`#todo-pin-${todoItem.dataset.todoId}`);
                  if (pinElement) {
                      pinElement.remove();
                  }
                }
              })
              .catch(error => {});
          }
        });
      });

      once('todo-share', '.icon-share-wrapper', context).forEach(function(iconWrapper) {
        iconWrapper.addEventListener('click', function() {
          const todoItem = this.closest('.todo-item');
          const todoId = todoItem.dataset.todoId;
          const isShared = this.dataset.shared === 'true';

          const newSharedState = !isShared;
          this.dataset.shared = newSharedState;

          if (newSharedState) {
            this.classList.add('active');
          } else {
            this.classList.remove('active');
          }

          fetch(`/todo/${todoId}/share`, {
            method: 'POST',
            headers: {
              'Content-Type': 'application/json',
            },
            body: JSON.stringify({ share: newSharedState })
          });
        });
      });
    }
  };
})(jQuery, Drupal, drupalSettings, once);
